@@ -1,13 +1,12 @@
 from geox.exceptions import APIKeyException, ParameterException, ServerErrorException
 from http import HTTPStatus
-from requests import request, Response
+from requests import request, Response, packages
 from requests.exceptions import ConnectionError, SSLError
-from requests.packages.urllib3.exceptions import InsecureRequestWarning
 from time import sleep
-import requests
+from urllib3.exceptions import InsecureRequestWarning
+import urllib3
 
-
-requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
+urllib3.disable_warnings(InsecureRequestWarning)
 
 
 def check_status_code(response: Response) -> None:
@@ -21,6 +20,7 @@ def check_status_code(response: Response) -> None:
     elif response.status_code == HTTPStatus.NOT_FOUND:
         raise ServerErrorException('404. Not Found response, server error.')
 
+
 def connect_to_endpoint(url: str, method: str, headers: dict={}, params:dict ={}, verify_ssl:bool=True) -> dict:
     '''Connect to endpoint'''
     try:
